:root{
  --ifm-color-primary-lightest: #68CF3E;
  --ifm-color-primary-lighter: #59BF2F;
  --ifm-color-primary-light: #55B72D;
  --ifm-color-primary: #4da629;
  --ifm-color-primary-dark: #459525;
  --ifm-color-primary-darker: #418D23;
  --ifm-color-primary-darkest: #36741D;
}
