
module.exports = {
  "docs": {
    "Tutorial": [
      "tutorial/get-started",
      "tutorial/scripts",
      "tutorial/data",
      "tutorial/data-structures",
      "tutorial/modules",
      "tutorial/logging",
      "tutorial/alerts",
      "tutorial/notebooks",
      "tutorial/deployments"
    ],
    "SOIL Library": [require("../docs/soil-library/sidebar.json")],
    "SDK Reference": [require("../docs/sdk-reference/sidebar.json")]
  }
}
