export default [
  require('/mnt/a32aae17-c247-4851-b81b-2ab2970c96e0/amalfi/soil-sdk/docs/website/node_modules/infima/dist/css/default/default.css'),
  require('/mnt/a32aae17-c247-4851-b81b-2ab2970c96e0/amalfi/soil-sdk/docs/website/node_modules/@docusaurus/theme-classic/lib/prism-include-languages'),
  require('/mnt/a32aae17-c247-4851-b81b-2ab2970c96e0/amalfi/soil-sdk/docs/website/node_modules/@docusaurus/theme-classic/lib/admonitions.css'),
  require('/mnt/a32aae17-c247-4851-b81b-2ab2970c96e0/amalfi/soil-sdk/docs/website/node_modules/@docusaurus/theme-classic/lib/nprogress'),
  require('/mnt/a32aae17-c247-4851-b81b-2ab2970c96e0/amalfi/soil-sdk/docs/website/src/css/customTheme.css'),
];
